==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_fields/GRIDPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GRIDPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GRIDPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDPARAMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GRIDPARAMETERID_Type", propOrder = {
    "gridid",
    "gridparamid"
})
public class GRIDPARAMETERID_Type {

    @XmlElement(name = "GRIDID")
    protected long gridid;
    @XmlElement(name = "GRIDPARAMID", required = true)
    protected String gridparamid;

    /**
     * Obtient la valeur de la propriété gridid.
     * 
     */
    public long getGRIDID() {
        return gridid;
    }

    /**
     * Définit la valeur de la propriété gridid.
     * 
     */
    public void setGRIDID(long value) {
        this.gridid = value;
    }

    /**
     * Obtient la valeur de la propriété gridparamid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDPARAMID() {
        return gridparamid;
    }

    /**
     * Définit la valeur de la propriété gridparamid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDPARAMID(String value) {
        this.gridparamid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/GRIDPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GRIDPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GRIDPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GRIDPARAMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GRIDPARAMETERID_Type", propOrder = {
    "gridid",
    "gridparamid"
})
public class GRIDPARAMETERID_Type {

    @XmlElement(name = "GRIDID")
    protected long gridid;
    @XmlElement(name = "GRIDPARAMID", required = true)
    protected String gridparamid;

    /**
     * Gets the value of the gridid property.
     * 
     */
    public long getGRIDID() {
        return gridid;
    }

    /**
     * Sets the value of the gridid property.
     * 
     */
    public void setGRIDID(long value) {
        this.gridid = value;
    }

    /**
     * Gets the value of the gridparamid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRIDPARAMID() {
        return gridparamid;
    }

    /**
     * Sets the value of the gridparamid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRIDPARAMID(String value) {
        this.gridparamid = value;
    }

}
